@@ -40,6 +40,9 @@ class MessageSet(models.Model):
     next_set = models.ForeignKey('self',
                                  null=True,
                                  blank=True)
+    default_schedule = models.ForeignKey(PeriodicTask,
+                                         related_name='message_sets',
+                                         null=False)
     created_at = AutoNewDateTimeField(blank=True)
     updated_at = AutoDateTimeField(blank=True)
 
@@ -117,6 +120,7 @@ def send_optional_first_message(sender, instance, created, **kwargs):
             conversation_key=settings.VUMI_GO_CONVERSATION_KEY,
             conversation_token=settings.VUMI_GO_ACCOUNT_TOKEN
         )
-        processes_message.delay(
-            instance, api_client,
+
+        processes_message.apply_async(
+            args=[instance.id, api_client],
             countdown=settings.SUBSCRIPTION_SEND_INITIAL_DELAYED)
