@@ -291,12 +291,12 @@ class TestMessageQueueProcessor(TestCase):
         messagesets = MessageSet.objects.all()
         self.assertEqual(len(messagesets), 10)
         subscriptions = Subscription.objects.all()
-        self.assertEqual(len(subscriptions), 5)
+        self.assertEqual(len(subscriptions), 6)
 
     def test_multisend(self):
         schedule = 6
         result = process_message_queue.delay(schedule, self.sender)
-        self.assertEquals(result.get(), 2)
+        self.assertEquals(result.get(), 3)
         # self.assertEquals(1, 2)
 
     def test_multisend_none(self):
@@ -305,8 +305,8 @@ class TestMessageQueueProcessor(TestCase):
         self.assertEquals(result.get(), 0)
 
     def test_send_message_1_en_accelerated(self):
-        subscriber = Subscription.objects.get(pk=1)
-        result = processes_message.delay(subscriber, self.sender)
+        subscription = Subscription.objects.get(pk=1)
+        result = processes_message.delay(subscription.id, self.sender)
         self.assertEqual(result.get(), {
             "message_id": result.get()["message_id"],
             "to_addr": "+271234",
@@ -317,50 +317,74 @@ class TestMessageQueueProcessor(TestCase):
         self.assertEquals(subscriber_updated.process_status, 0)
 
     def test_next_message_2_post_send_en_accelerated(self):
-        subscriber = Subscription.objects.get(pk=1)
-        result = processes_message.delay(subscriber, self.sender)
+        subscription = Subscription.objects.get(pk=1)
+        result = processes_message.delay(subscription.id, self.sender)
         self.assertTrue(result.successful())
         subscriber_updated = Subscription.objects.get(pk=1)
         self.assertEquals(subscriber_updated.next_sequence_number, 2)
 
     def test_set_completed_post_send_en_accelerated_2(self):
-        subscriber = Subscription.objects.get(pk=1)
-        subscriber.next_sequence_number = 2
-        subscriber.save()
-        result = processes_message.delay(subscriber, self.sender)
+        subscription = Subscription.objects.get(pk=1)
+        subscription.next_sequence_number = 2
+        subscription.save()
+        result = processes_message.delay(subscription.id, self.sender)
         self.assertTrue(result.successful())
         subscriber_updated = Subscription.objects.get(pk=1)
         self.assertEquals(subscriber_updated.completed, True)
         self.assertEquals(subscriber_updated.active, False)
 
     def test_new_subscription_created_post_send_en_accelerated_2(self):
-        subscriber = Subscription.objects.get(pk=1)
-        subscriber.next_sequence_number = 2
-        subscriber.save()
-        result = processes_message.delay(subscriber, self.sender)
+        subscription = Subscription.objects.get(pk=1)
+        subscription.next_sequence_number = 2
+        subscription.save()
+        result = processes_message.delay(subscription.id, self.sender)
         self.assertTrue(result.successful())
         # Check another added and old still there
         all_subscription = Subscription.objects.all()
-        self.assertEquals(len(all_subscription), 6)
+        self.assertEquals(len(all_subscription), 7)
         # Check new subscription is for baby1
-        new_subscription = Subscription.objects.get(pk=6)
+        new_subscription = Subscription.objects.get(pk=7)
         self.assertEquals(new_subscription.message_set.pk, 4)
         self.assertEquals(new_subscription.to_addr, "+271234")
+        # make sure the new sub is on a different schedule
+        periodictask = PeriodicTask.objects.get(pk=2)
+        self.assertEquals(new_subscription.schedule, periodictask)
 
-    def test_no_new_subscription_created_post_send_en_accelerated_2(self):
-        subscriber = Subscription.objects.get(pk=4)
-        result = processes_message.delay(subscriber, self.sender)
+    def test_no_new_subscription_created_post_send_en_baby_2(self):
+        subscription = Subscription.objects.get(pk=4)
+        result = processes_message.delay(subscription.id, self.sender)
         self.assertTrue(result.successful())
         # Check no new subscription added
         all_subscription = Subscription.objects.all()
-        self.assertEquals(len(all_subscription), 5)
+        self.assertEquals(len(all_subscription), 6)
         # Check old one now inactive and complete
         subscriber_updated = Subscription.objects.get(pk=4)
         self.assertEquals(subscriber_updated.completed, True)
         self.assertEquals(subscriber_updated.active, False)
 
+    def test_send_3_part_message_1_en_subscription(self):
+        subscription = Subscription.objects.get(pk=6)
+        result = processes_message.delay(subscription.id, self.sender)
+        self.assertEqual(result.get(), [{
+            "message_id": result.get()[0]["message_id"],
+            "to_addr": "+271113",
+            "content": "Message 1 on subscription PT1",
+        }, {
+            "message_id": result.get()[1]["message_id"],
+            "to_addr": "+271113",
+            "content": "Message 1 on subscription PT2",
+        }, {
+            "message_id": result.get()[2]["message_id"],
+            "to_addr": "+271113",
+            "content": "Message 1 on subscription PT3",
+        }])
+        subscriber_updated = Subscription.objects.get(pk=6)
+        self.assertEquals(subscriber_updated.next_sequence_number, 2)
+        self.assertEquals(subscriber_updated.process_status, 0)
+
 
 class RecordingAdapter(TestAdapter):
+
     """ Record the request that was handled by the adapter.
     """
     request = None
@@ -371,6 +395,7 @@ class RecordingAdapter(TestAdapter):
 
 
 class TestHttpApiSender(TestCase):
+
     def setUp(self):
         self.session = TestSession()
         self.sender = HttpApiSender(
@@ -451,6 +476,7 @@ class TestHttpApiSender(TestCase):
 
 
 class RecordingHandler(logging.Handler):
+
     """ Record logs. """
     logs = None
 
@@ -461,6 +487,7 @@ class RecordingHandler(logging.Handler):
 
 
 class TestLoggingSender(TestCase):
+
     def setUp(self):
         self.sender = LoggingSender('go_http.test')
         self.handler = RecordingHandler()
